
/* Generated data (by glib-mkenums) */

#ifndef __ENUM_GTYPES_H__
#define __ENUM_GTYPES_H__
#include <glib-object.h>
G_BEGIN_DECLS
/* enumerations from "parole-button.h" */
GType parole_button_key_get_type (void);
#define ENUM_GTYPE_BUTTON_KEY (parole_button_key_get_type())
G_END_DECLS

#endif /* __ENUM_GTYPES_H__ */

/* Generated data ends here */

